<?php

/**
 * Wp in Progress
 *
 * @package Wordpress
 * @theme Sueva
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * It is also available at this URL: http://www.gnu.org/licenses/gpl-3.0.txt
 */

/*-----------------------------------------------------------------------------------*/
/* Woocommerce is active */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'ctyp_is_woocommerce_active' ) ) {

	function ctyp_is_woocommerce_active( $type = '' ) {

		global $woocommerce;

		if ( isset( $woocommerce ) ) {

			if ( !$type || call_user_func($type) ) {

				return true;

			}

		}

	}

}

/*-----------------------------------------------------------------------------------*/
/* ALLOWED TAGS */
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'ctyp_allowed_tags' ) ) {

	function ctyp_allowed_tags( $content = '' ) {

		$replace = array (
			'/(<(script|noscript|style)\b[^>]*>).*?(<\/\2>)/is',
			'/(&lt;(script|noscript|style)\b[^>]*&gt;).*?(&lt;\/\2&gt;)/is',
		);

		$content = preg_replace ($replace, '', $content);

		$allowed_atts = array(
			'align'      => array(),
			'class'      => array(),
			'type'       => array(),
			'id'         => array(),
			'dir'        => array(),
			'lang'       => array(),
			'style'      => array(),
			'xml:lang'   => array(),
			'src'        => array(),
			'alt'        => array(),
			'href'       => array(),
			'rel'        => array(),
			'rev'        => array(),
			'target'     => array(),
			'novalidate' => array(),
			'type'       => array(),
			'value'      => array(),
			'name'       => array(),
			'tabindex'   => array(),
			'action'     => array(),
			'method'     => array(),
			'for'        => array(),
			'width'      => array(),
			'height'     => array(),
			'data'       => array(),
			'title'      => array(),
		);

		$allowedposttags['form']     = $allowed_atts;
		$allowedposttags['label']    = $allowed_atts;
		$allowedposttags['input']    = $allowed_atts;
		$allowedposttags['textarea'] = $allowed_atts;
		$allowedposttags['iframe']   = $allowed_atts;
		$allowedposttags['strong']   = $allowed_atts;
		$allowedposttags['small']    = $allowed_atts;
		$allowedposttags['table']    = $allowed_atts;
		$allowedposttags['span']     = $allowed_atts;
		$allowedposttags['abbr']     = $allowed_atts;
		$allowedposttags['code']     = $allowed_atts;
		$allowedposttags['pre']      = $allowed_atts;
		$allowedposttags['div']      = $allowed_atts;
		$allowedposttags['img']      = $allowed_atts;
		$allowedposttags['h1']       = $allowed_atts;
		$allowedposttags['h2']       = $allowed_atts;
		$allowedposttags['h3']       = $allowed_atts;
		$allowedposttags['h4']       = $allowed_atts;
		$allowedposttags['h5']       = $allowed_atts;
		$allowedposttags['h6']       = $allowed_atts;
		$allowedposttags['ol']       = $allowed_atts;
		$allowedposttags['ul']       = $allowed_atts;
		$allowedposttags['li']       = $allowed_atts;
		$allowedposttags['em']       = $allowed_atts;
		$allowedposttags['hr']       = $allowed_atts;
		$allowedposttags['br']       = $allowed_atts;
		$allowedposttags['tr']       = $allowed_atts;
		$allowedposttags['td']       = $allowed_atts;
		$allowedposttags['p']        = $allowed_atts;
		$allowedposttags['a']        = $allowed_atts;
		$allowedposttags['b']        = $allowed_atts;
		$allowedposttags['i']        = $allowed_atts;

		return wp_kses($content, $allowedposttags);

	}

}

/*-----------------------------------------------------------------------------------*/
/* SETTINGS */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('ctyp_setting')) {

	function ctyp_setting($id, $default = '' ) {

		$settings = get_option('ctp_settings');

		if(isset($settings[$id]) && !empty($settings[$id])):

			return $settings[$id];

		else:

			return $default;

		endif;

	}

}

/*-----------------------------------------------------------------------------------*/
/* AJAX POSTS LIST */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('ctyp_get_ajax_list_posts')) {

	function ctyp_get_ajax_list_posts() {

		global $wpdb;

		$result = array();

		$post_type = sanitize_text_field($_REQUEST['ctyp_post_type']);
		$search = sanitize_text_field($_GET['q']);

		if (strpos($search, '[Al') !== false || strpos($search, '[al') !== false) {

			$result[] = array(
				'text' => '[All]',
				'id' => '-1',
			);

		} else {

			add_filter('posts_where', function( $where ) use ($search) {
				$where .= (" AND post_title LIKE '%" . $search . "%'");
				return $where;
			});

			$query = array(
				'posts_per_page' => -1,
				'post_status' => 'publish',
				'post_type' => $post_type,
				'order' => 'ASC',
				'orderby' => 'title',
				'suppress_filters' => false,
			);

			$posts = get_posts( $query );

			foreach ($posts as $this_post) {

				$post_title = $this_post->post_title;
				$id = $this_post->ID;

				$result[] = array(
					'text' => esc_html($post_title),
					'id' => esc_attr($id),
				);

			}

		}

		$posts['items'] = $result;
		echo json_encode($posts);
		die();

	}

	add_action( 'wp_ajax_ctyp_list_posts', 'ctyp_get_ajax_list_posts' );

}

/*-----------------------------------------------------------------------------------*/
/* AJAX TAXONOMY LIST */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('ctyp_get_ajax_list_taxonomy')) {

	function ctyp_get_ajax_list_taxonomy() {

		global $wpdb;

		$result = array();
		$search = sanitize_text_field($_GET['q']);

		if (strpos($search, '[Al') !== false || strpos($search, '[al') !== false) {

			$result[] = array(
				'text' => '[All]',
				'id' => '-1',
			);

		} else {

			$args = array(
				'taxonomy' => sanitize_text_field($_REQUEST['ctyp_taxonomy_type']),
				'hide_empty' => false,
				'name__like' => $search
			);

			foreach ( get_terms($args) as $cat) {
				$result[] = array(
					'text' => esc_html($cat->name),
					'id' => esc_attr($cat->term_id),
				);
			}

		}

		$terms['items'] = $result;
		echo json_encode($terms);
		die();

	}

	add_action( 'wp_ajax_ctyp_list_taxonomy', 'ctyp_get_ajax_list_taxonomy' );

}

?>
