<?php

// Exit if accessed directly
if (!defined('ABSPATH')) exit;

if( !class_exists( 'ctyp_panel' ) ) {

	class ctyp_panel {

		/**
		 * Constructor
		 */

		public function __construct( $fields = array() ) {

			$this->panel_fields = $fields;

			$this->plugin_slug = 'ctyp_panel_';
			$this->plugin_optionname = 'ctp_settings';

			add_action('admin_menu', array(&$this, 'admin_menu') ,11);
			add_action('admin_init', array(&$this, 'add_content') ,11);
			add_action('admin_init', array(&$this, 'save_option') ,11);

		}

		/**
		 * Create option panel menu
		 */

		public function admin_menu() {

			global $admin_page_hooks;

            if ( !isset( $admin_page_hooks['tip_plugins_panel']) ) :

				add_menu_page(
					esc_html__('TIP Plugins', 'custom-thank-you-page'),
					esc_html__('TIP Plugins', 'custom-thank-you-page'),
					'manage_options',
					'tip_plugins_panel',
					NULL,
					plugins_url('/assets/images/icon.png', dirname(__FILE__)),
					64
				);

			endif;

			add_submenu_page(
				'tip_plugins_panel',
				esc_html__('Custom Thank You Page', 'custom-thank-you-page'),
				esc_html__('Custom Thank You Page', 'custom-thank-you-page'),
				'manage_options',
				'ctyp_panel',
				array(&$this, 'ctyp_panel')
			);

			if ( isset( $admin_page_hooks['tip_plugins_panel'] ) )
				remove_submenu_page( 'tip_plugins_panel', 'tip_plugins_panel' );

		}

		/**
		 * Loads the plugin scripts and styles
		 */

		public function add_content() {

			 global $wp_version, $pagenow;

			 $file_dir = plugins_url('/assets/', dirname(__FILE__));

			 wp_enqueue_style ( 'ctyp_notice', $file_dir.'css/notice.css' );

			 if ( $pagenow == 'admin.php' ) {

				wp_enqueue_style ( 'ctyp_panel_panel', $file_dir.'css/panel.css' );
				wp_enqueue_style ( 'ctyp_panel_freepro', $file_dir.'css/freepro.css' );
				wp_enqueue_style ( 'ctyp_panel_on_off', $file_dir.'css/on_off.css' );
				wp_enqueue_style ( 'ctyp_panel_googlefonts', '//fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i');
				wp_enqueue_style ( 'ctyp_panel_select2', $file_dir.'css/select2.min.css' );

				wp_enqueue_script( 'jquery');
				wp_enqueue_script( 'jquery-ui-core', array('jquery'));
				wp_enqueue_script( 'jquery-ui-tabs', array('jquery'));
			 	wp_enqueue_script( 'jquery-ui-sortable', array('jquery'));

				wp_enqueue_script( 'ctyp_panel_on_off', $file_dir.'js/on_off.js','3.5', '', TRUE);
				wp_enqueue_script( 'ctyp_panel_select2', $file_dir.'js/select2.min.js','3.5', '', TRUE);
				wp_enqueue_script( 'ctyp_panel', $file_dir.'js/panel.js',array('jquery','thickbox'),'1.0',TRUE );

			 }

		}

		/**
		 * Message after the options saving
		 */

		public function save_message () {

			global $ctyp_message;
			$plugin_slug = $this->plugin_slug;

			if (isset($ctyp_message))
				echo '<div id="message" class="updated fade message_save ' . $plugin_slug . 'message"><p><strong> ' . $ctyp_message . '</strong></p></div>';

		}

		/**
		 * Sanitize boolean function
		 */

		public function sanitize_bool_function($k) {

			return ( $k == 'on' ) ? 'on' : 'off';

		}

		/**
		 * Sanitize matchValue function
		 */

		public function sanitize_matchValue_function($k) {

			return ( $k == 'include' ) ? 'include' : 'exclude';

		}

		/**
		 * Sanitize content position function
		 */

		public function sanitize_content_position($k) {

			$positionArray = array(
				'woocommerce_before_thankyou',
				'woocommerce_thankyou'
			);

			if ( in_array($k, $positionArray)) {

				return $k;

			} else {

				return 'woocommerce_thankyou';

			}

		}

		/**
		 * Sanitize matchValue function
		 */

		public function sanitize_postID_function($k) {

			if ( is_array($k) ) :

				if (in_array('-1', $k)) {

					return array('-1');

				} else {

					foreach ($k as $v) {

						$postTitle = sanitize_text_field(get_the_title($v));

						if ( true == post_exists($postTitle) ) {

							$error = false;

						} elseif ( false == post_exists($postTitle) ) {

							$error = true;

						}

					}

					return ($error == false ) ? $k : array('-1');

				}

			else:

				return array('-1');

			endif;

		}

		/**
		 * Multidimensional Array sanitize function
		 */

		public function array_sanitize_function($array, $contentID) {

			$tosave = array();

			$tosave['name'] = sanitize_text_field($array['content' . $contentID]['name']);
			$tosave['product_matchValue'] = $this->sanitize_matchValue_function($array['content' . $contentID]['product_matchValue']);
			$tosave['include_product'] = $this->sanitize_postID_function($array['content' . $contentID]['include_product']);
			$tosave['exclude_product'] = $this->sanitize_postID_function($array['content' . $contentID]['exclude_product']);
			$tosave['order_details'] = $this->sanitize_bool_function($array['content' . $contentID]['order_details']);
			$tosave['position'] = $this->sanitize_content_position($array['content' . $contentID]['position']);
			$tosave['content'] = ctyp_allowed_tags($array['content' . $contentID]['content']);

			return $tosave;

		}

		/**
		 * Save options function
		 */

		public function save_option() {

			global $ctyp_message;

			$ctyp_setting = get_option($this->plugin_optionname);

			if ( $ctyp_setting != false ) :

				$ctyp_setting = maybe_unserialize( get_option( $this->plugin_optionname ) );

			else :

				$ctyp_setting = array();

			endif;

			if (isset($_GET['action']) && ($_GET['action'] == 'ctyp_backup_download')) {

				header("Cache-Control: public, must-revalidate");
				header("Pragma: hack");
				header("Content-Type: text/plain");
				header('Content-Disposition: attachment; filename="ctyp_backup.dat"');
				echo serialize($this->get_options());
				exit;

			}

			if (isset($_GET['action']) && ($_GET['action'] == 'ctyp_backup_reset')) {

				update_option( $this->plugin_optionname,'');
				wp_redirect(admin_url('admin.php?page=ctyp_panel&tab=Import_Export'));
				exit;

			}

			if (isset($_POST['ctyp_upload_backup']) && check_admin_referer('ctyp_restore_options', 'ctyp_restore_options')) {

				if ($_FILES["ctyp_upload_file"]["error"] <= 0) {

					$options = unserialize(file_get_contents($_FILES["ctyp_upload_file"]["tmp_name"]));

					if ($options) {

						foreach ($options as $option) {
							update_option( $this->plugin_optionname, unserialize($option->option_value));

						}

					}

				}

				wp_redirect(admin_url('admin.php?page=ctyp_panel&tab=Import_Export'));
				exit;

			}

			if ( $this->ctyp_request('ctyp_new_content_action') !== null ) {

				$lastSlot = key(array_slice($ctyp_setting['ctyp_generator'], -1, 1, true));
				$newSlot = str_replace('content', '', $lastSlot) + 1;
				$ctyp_setting['ctyp_generator']['content' . $newSlot] = array('name' => esc_html__('Undefined content ','custom-thank-you-page') . $newSlot);
				update_option($this->plugin_optionname, $ctyp_setting);
				wp_redirect(admin_url('admin.php?page=ctyp_panel&tab=Content_Generator&contentID=' . $newSlot));

			}

			if ( $this->ctyp_request('ctyp_delete_content_action') !== null ) {

				unset($ctyp_setting['ctyp_generator']['content' . $_POST['ctyp_content_id']]);
				update_option($this->plugin_optionname, $ctyp_setting);

			}

			if ( $this->ctyp_request('ctyp_save_content_action') !== null ) {

				foreach ( $this->panel_fields as $element ) {

					if ( isset($element['tab']) && $element['tab'] == $_GET['tab'] ) {

						foreach ($element as $value ) {

							if ( isset($value['id']) && ( $value['id'] == 'ctyp_generator' ) ) {

								if ( isset($_POST[$value["id"]]) ) {

									$contentID = absint($_POST['ctyp_content_id']);
									$ctyp_setting['ctyp_generator']['content'. $contentID] = $this->array_sanitize_function($_POST[$value["id"]], $contentID);
									update_option($this->plugin_optionname, $ctyp_setting );

								} else {

									unset($ctyp_setting['ctyp_generator']);
									update_option( $this->plugin_optionname, $ctyp_setting );

								}

							}

							$ctyp_message = esc_html__('Options saved successfully.', 'custom-thank-you-page' );

						}

					}

				}

			}

		}

		/**
		 * Get options
		 */

		public function get_options() {

			global $wpdb;
			return $wpdb->get_results("SELECT option_name, option_value FROM {$wpdb->options} WHERE option_name = '".$this->plugin_optionname."'");

		}

		/**
		 * Request function
		 */

		public function ctyp_request($id) {

			if (isset($_REQUEST[$id]))
				return esc_html($_REQUEST[$id]);

		}

		/**
		 * Option panel
		 */

		public function ctyp_panel() {

			global $ctyp_message;

			$ctypForm = new ctyp_form();
			$plugin_slug =  $this->plugin_slug;

			if (!isset($_GET['tab']))
				$_GET['tab'] = "Content_Generator";

			foreach ( $this->panel_fields as $element) {

				if (isset($element['type'])) :

					switch ( $element['type'] ) {

						case 'navigation':

							echo $ctypForm->elementStart('div', $plugin_slug . 'tabs', FALSE );

								echo $ctypForm->elementStart('div', $plugin_slug . 'header', FALSE );

									echo $ctypForm->elementStart('div', FALSE, 'left plugin_description' );

										echo $ctypForm->element('h2', FALSE, 'maintitle', esc_html__( 'Custom Thank You Page for WooCommerce','custom-thank-you-page'));
										echo $ctypForm->element('span', FALSE, FALSE, esc_html__( 'Version: ','custom-thank-you-page') . CTYP_VERSION);
										echo $ctypForm->link('https://www.themeinprogress.com', FALSE, FALSE, '_blank', FALSE, esc_html__( 'by ThemeinProgress','custom-thank-you-page') );
										echo $ctypForm->link(CTYP_DEMO_URL, FALSE, FALSE, '_blank', FALSE, esc_html__( ' - Documentation','custom-thank-you-page') );

									echo $ctypForm->elementEnd('div');

									echo $ctypForm->element('div', FALSE, 'clear', FALSE);

								echo $ctypForm->elementEnd('div');

								$this->save_message();

								echo $ctypForm->htmlList('ul', FALSE, $plugin_slug . 'navigation', $element['item'], esc_attr($_GET['tab']));

						break;

						case 'end-tab':

								echo $ctypForm->element('div', FALSE, 'clear', FALSE);

							echo $ctypForm->elementEnd('div');

						break;

					}

				endif;

			if (isset($element['tab'])) :

				switch ( $element['tab'] ) {

					case esc_attr($_GET['tab']):

						foreach ($element as $value) {

							if (isset($value['type'])) :

								switch ( $value['type'] ) {

								case 'start-form':

									echo $ctypForm->elementStart('div', str_replace(' ', '', $value['name']), FALSE );

										echo $ctypForm->formStart('post', '?page=ctyp_panel&tab=' . esc_attr($_GET['tab']) );

								break;

								case 'end-form':

										echo $ctypForm->formEnd();

									echo $ctypForm->elementEnd('div');

								break;

								case 'start-container':

									$class = ( 'Save' == $this->ctyp_request('ctyp_action') && $value['val'] == $this->ctyp_request('element-opened') ) ? ' inactive' : '';

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'container' );

										echo $ctypForm->element('h5', $value['val'], 'element ' . $class, $value['name'] );

										echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'mainbox' );

								break;

								case 'start-open-container':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'container' );

										echo $ctypForm->element('h5', FALSE, 'element-open', $value['name'] );

										echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'mainbox ctyp_openbox' );

								break;

								case 'end-container':

										echo $ctypForm->elementEnd('div');

									echo $ctypForm->elementEnd('div');

								break;

								case 'checkbox':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label($value['id'], $value['name']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->checkbox($value['id'], $value['options'], ctyp_setting($value['id']));
											echo $ctypForm->element('p', FALSE, FALSE, $value['desc']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case 'text':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label($value['id'], $value['name']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->input($value['id'], $value['id'], FALSE, $value['type'], ctyp_setting($value['id'], $value['std']));
											echo $ctypForm->element('p', FALSE, FALSE, $value['desc']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case "upload":

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label($value['id'], $value['name']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->input($value['id'], $value['id'], 'upload_attachment', 'text', ctyp_setting($value['id'], $value['std']));
											echo $ctypForm->element('p', FALSE, FALSE, $value['desc']);
											echo $ctypForm->input(FALSE, FALSE, 'button upload_button', 'button', esc_attr__('Upload', 'custom-thank-you-page'));

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case 'textarea':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label($value['id'], $value['name']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->textarea($value['id'], $value['id'], FALSE, ctyp_setting($value['id'], $value['std']), FALSE);
											echo $ctypForm->element('p', FALSE, FALSE, $value['desc']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case 'on-off':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label($value['id'], $value['name']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->elementStart('div', FALSE,  $plugin_slug . 'slider ' . ctyp_setting($value['id'], $value['std']) );

												echo $ctypForm->elementStart('div', FALSE, 'inset' );
												echo $ctypForm->element('div', FALSE, 'control', FALSE);
												echo $ctypForm->elementEnd('div');

												echo $ctypForm->input($value['id'], $value['id'], 'on-off', 'hidden', ctyp_setting($value['id'], $value['std']));

											echo $ctypForm->elementEnd('div');

											echo $ctypForm->element('div', FALSE, 'clear', FALSE);
											echo $ctypForm->element('p', FALSE, FALSE, $value['desc'] );

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case 'select':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label($value['id'], $value['name']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->select($value['id'], $value['id'], FALSE, $value['options'], ctyp_setting($value['id'], $value['std']), FALSE);
											echo $ctypForm->element('p', FALSE, FALSE, $value['desc']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case 'AjaxSelect2':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label($value['id'], $value['name']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->ajaxSelect($value['id'], $value['id'], $value['class'], ctyp_setting($value['id']), $value['dataType']);
											echo $ctypForm->element('p', FALSE, FALSE, $value['desc']);

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case "save-button":

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box WIP_plugin_save_box');

										echo $ctypForm->input($value['action'], FALSE, 'button', 'submit', $value['value']);

									echo $ctypForm->elementEnd('div');

								break;

								case 'import_export':

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label(FALSE, esc_html__('Current plugin settings','custom-thank-you-page'));

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->textarea(FALSE, FALSE, 'widefat code', serialize($this->get_options()), TRUE);
											$exportURL = esc_url('?page=ctyp_panel&tab=Import_Export&action=ctyp_backup_download');
											echo $ctypForm->link($exportURL, FALSE, 'button button-secondary', '_self', FALSE, esc_html__( 'Download current plugin settings','custom-thank-you-page') );

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label(FALSE, esc_html__('Reset plugin settings','custom-thank-you-page'));

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											$resetURL = esc_url('?page=ctyp_panel&tab=Import_Export&action=ctyp_backup_reset');
											echo $ctypForm->link($resetURL, FALSE, 'button-secondary ctyp_restore_settings', '_self', FALSE, esc_html__( 'Reset plugin settings','custom-thank-you-page') );

											echo $ctypForm->element('p', FALSE, FALSE, esc_html__( 'If you click the button above, the plugin options return to its default values','custom-thank-you-page'));

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

									echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

										echo $ctypForm->elementStart('div', FALSE, 'input-left' );

											echo $ctypForm->label(FALSE, esc_html__('Import plugin settings','custom-thank-you-page'));

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->elementStart('div', FALSE, 'input-right' );

											echo $ctypForm->input('ctyp_upload_file', FALSE, FALSE, 'file', FALSE);
											echo $ctypForm->input('ctyp_upload_backup', 'ctyp_upload_backup', 'button-primary', 'submit', esc_html__( 'Import plugin settings','custom-thank-you-page'));
											function_exists('wp_nonce_field') ? wp_nonce_field('ctyp_restore_options', 'ctyp_restore_options') : '' ;

										echo $ctypForm->elementEnd('div');

										echo $ctypForm->element('div', FALSE, 'clear', FALSE);

									echo $ctypForm->elementEnd('div');

								break;

								case 'free_vs_pro':

								echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

									echo $ctypForm->tableStart(FALSE, $plugin_slug . ' card table free-pro', 0, 0 );

									echo $ctypForm->tableElementStart('tbody', FALSE, 'table-body');

										echo $ctypForm->tableElementStart('tr', FALSE, 'table-head');

											echo $ctypForm->tableElement('th', FALSE, 'large');

											echo $ctypForm->tableElementStart('th', FALSE, 'indicator');
												echo esc_html__('Free', 'custom-thank-you-page');
											echo $ctypForm->tableElementEnd('th');

											echo $ctypForm->tableElementStart('th', FALSE, 'indicator');
												echo esc_html__('Premium', 'custom-thank-you-page');
											echo $ctypForm->tableElementEnd('th');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Custom thank you page for all products', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE );

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Custom thank you page for specific products', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE );

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Advanced combinations and exclusions', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE );

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Enable/disable the order details table', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE );

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Device selection', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

													echo $ctypForm->elementStart('div', FALSE, 'feature-inline-row' );

														echo $ctypForm->element('span', FALSE, 'info-icon dashicon dashicons dashicons-info', FALSE );

														echo $ctypForm->elementStart('span', FALSE, 'feature-description' );

															echo esc_html__('Select one or more devices where you can load the custom content on thank you page.', 'custom-thank-you-page');

														echo $ctypForm->elementEnd('span');

													echo $ctypForm->elementEnd('div');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-no-alt', FALSE);

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Dynamics user data', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

													echo $ctypForm->elementStart('div', FALSE, 'feature-inline-row' );

														echo $ctypForm->element('span', FALSE, 'info-icon dashicon dashicons dashicons-info', FALSE );

														echo $ctypForm->elementStart('span', FALSE, 'feature-description' );

															echo esc_html__('The dynamic user data allow you to display a specific parameters of a WooCommerce order inside your thank you page, like the order ID or the first name..', 'custom-thank-you-page');

														echo $ctypForm->elementEnd('span');

													echo $ctypForm->elementEnd('div');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-no-alt', FALSE);

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Dynamics user data generator', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

													echo $ctypForm->elementStart('div', FALSE, 'feature-inline-row' );

														echo $ctypForm->element('span', FALSE, 'info-icon dashicon dashicons dashicons-info', FALSE );

														echo $ctypForm->elementStart('span', FALSE, 'feature-description' );

															echo esc_html__('You can load a specific dynamics user data inside the final thank you page.', 'custom-thank-you-page');

														echo $ctypForm->elementEnd('span');

													echo $ctypForm->elementEnd('div');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-no-alt', FALSE);

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Custom thank you page for all products on specific category', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

													echo $ctypForm->elementStart('div', FALSE, 'feature-inline-row' );

														echo $ctypForm->element('span', FALSE, 'info-icon dashicon dashicons dashicons-info', FALSE );

														echo $ctypForm->elementStart('span', FALSE, 'feature-description' );

															echo esc_html__('Set up the final thank you page for all products inside one or more product categories.', 'custom-thank-you-page');

														echo $ctypForm->elementEnd('span');

													echo $ctypForm->elementEnd('div');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-no-alt', FALSE);

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Custom thank you page for all products, based of the order amount', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

													echo $ctypForm->elementStart('div', FALSE, 'feature-inline-row' );

														echo $ctypForm->element('span', FALSE, 'info-icon dashicon dashicons dashicons-info', FALSE );

														echo $ctypForm->elementStart('span', FALSE, 'feature-description' );

															echo esc_html__('If needed, you can display a thank you page when the amount of an order is higher than a specific value.', 'custom-thank-you-page');

														echo $ctypForm->elementEnd('span');

													echo $ctypForm->elementEnd('div');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-no-alt', FALSE);

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'feature-row');

											echo $ctypForm->tableElementStart('td', FALSE, 'large');

												echo $ctypForm->elementStart('div', FALSE, 'feature-wrap' );

													echo $ctypForm->elementStart('h4', FALSE, FALSE );

														echo esc_html__('Custom thank you page for all products, based of the gateway ID

								', 'custom-thank-you-page');

													echo $ctypForm->elementEnd('h4');

													echo $ctypForm->elementStart('div', FALSE, 'feature-inline-row' );

														echo $ctypForm->element('span', FALSE, 'info-icon dashicon dashicons dashicons-info', FALSE );

														echo $ctypForm->elementStart('span', FALSE, 'feature-description' );

															echo esc_html__('If needed, you can display a thank you page when an user complete the order using a specific payment gateway, like PayPal or a bank transfer.', 'custom-thank-you-page');

														echo $ctypForm->elementEnd('span');

													echo $ctypForm->elementEnd('div');

												echo $ctypForm->elementEnd('div');

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-no-alt', FALSE);

											echo $ctypForm->tableElementEnd('td');

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->element('span', FALSE, 'dashicon dashicons dashicons-yes', FALSE);

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

										echo $ctypForm->tableElementStart('tr', FALSE, 'upsell-row');

											echo $ctypForm->tableElement('td', FALSE, FALSE);
											echo $ctypForm->tableElement('td', FALSE, FALSE);

											echo $ctypForm->tableElementStart('td', FALSE, 'indicator');

												echo $ctypForm->link(esc_url(CTYP_UPGRADE_LINK . '/?ref=2&campaign=ctyp-freepro'), FALSE, 'button button-primary', '_blank', FALSE, esc_html__( 'Upgrade to Premium','custom-thank-you-page') );

											echo $ctypForm->tableElementEnd('td');

										echo $ctypForm->tableElementEnd('tr');

									echo $ctypForm->tableElementEnd('tbody');

									echo $ctypForm->tableEnd();

								echo $ctypForm->elementEnd('div');

								break;

								case 'contentGenerator':

									$ctyp_setting = ctyp_setting($value['id']);

									echo $ctypForm->elementStart('div', FALSE, 'ctyp_contentGenerator' );

										echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'page_order' );

										if (!isset($_REQUEST['contentID'])) {

											if ($ctyp_setting) {

												foreach ($ctyp_setting as $k => $v) {

													echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'container' );

														echo $ctypForm->element('h5', FALSE, 'element linkable-element', '<a href="?page=ctyp_panel&tab=' . esc_attr($_GET['tab']) .'&contentID='.str_replace('content','',$k).'">'.$v['name'].'</a>' );

													echo $ctypForm->elementEnd('div');

												}

											}

											$ctypCount = is_array(ctyp_setting($value['id'])) ? count(ctyp_setting($value['id'])) : 0;

											if (
												(null !== ctyp_setting($value['id'])) &&
												is_array(ctyp_setting($value['id'])) &&
												$ctypCount >= 3
											) :

												echo $ctypForm->element('p', FALSE, FALSE, _e('<span>You have reached the limit of 3 contents. You can unlock this limit visiting this LINK</span> ','custom-thank-you-page'));
												echo $ctypForm->link(esc_url(CTYP_UPGRADE_LINK  . '/?ref=ctyp-panel'), FALSE, FALSE, '_blank', FALSE, esc_html__( 'Upgrade to Custom Thank You Page Pro','custom-thank-you-page') );

											else:

												echo $ctypForm->element('p', FALSE, FALSE, _e('<span>You are using ' . $ctypCount . ' contents or 3 available contents in the FREE version. You can unlock this limit visiting this LINK</span> ','custom-thank-you-page'));
												echo $ctypForm->link(esc_url(CTYP_UPGRADE_LINK  . '/?ref=ctyp-panel'), FALSE, FALSE, '_blank', FALSE, esc_html__( 'Upgrade to Custom Thank You Page Pro','custom-thank-you-page') );
												echo $ctypForm->input('ctyp_new_content_action', FALSE, 'button ctyp-new-content', 'submit', esc_html__( 'New content','custom-thank-you-page'));

											endif;


										} else {

											$contentID = absint($_REQUEST['contentID']);

											if (!array_key_exists('content' . $contentID, $ctyp_setting)) {
												wp_redirect(admin_url('admin.php?page=ctyp_panel&tab=Content_Generator'));
											}

											echo $ctypForm->input('ctyp_content_id', FALSE, FALSE, 'hidden', $contentID);

												echo $ctypForm->elementStart('div', 'content' . $contentID, $plugin_slug . 'container ');

													echo $ctypForm->element('h5', FALSE, 'element', ($ctyp_setting['content' . $contentID]['name']) ? esc_html($ctyp_setting['content' . $contentID]['name']) : esc_html__('Undefined page.', 'custom-thank-you-page' ) );

													echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'mainbox-open' );

														echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

															echo $ctypForm->elementStart('div', FALSE, 'input-left' );

																echo $ctypForm->label(FALSE, esc_html__( 'Page name.', 'custom-thank-you-page'));

															echo $ctypForm->elementEnd('div');

															echo $ctypForm->elementStart('div', FALSE, 'input-right' );

																echo $ctypForm->input($value['id'].'[content' . $contentID . '][name]', FALSE, FALSE, 'text', ($ctyp_setting['content' . $contentID]['name']) ? esc_html($ctyp_setting['content' . $contentID]['name']) : 'Undefined page');
																echo $ctypForm->element('p', FALSE, FALSE, esc_html__('Add the name of this page.','custom-thank-you-page'));

															echo $ctypForm->elementEnd('div');

															echo $ctypForm->element('div', FALSE, 'clear', FALSE);

														echo $ctypForm->elementEnd('div');

														foreach ( array('product') as $cpt ) {

															echo $ctypForm->elementStart('div', FALSE, FALSE);

																echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

																	echo $ctypForm->elementStart('div', FALSE, 'input-left' );

																		echo $ctypForm->label(FALSE, esc_html__( 'Products filter type.', 'custom-thank-you-page'));

																	echo $ctypForm->elementEnd('div');

																	echo $ctypForm->elementStart('div', FALSE, 'input-right' );

																		$postMatch = isset($ctyp_setting['content' . $contentID][$cpt . '_matchValue']) ? $this->sanitize_matchValue_function($ctyp_setting['content' . $contentID][$cpt . '_matchValue']) : array();

																		$options = array(
																			'include' => esc_html__('Include','custom-thank-you-page'),
																			'exclude' => esc_html__('Exclude','custom-thank-you-page')

																		);

																		echo $ctypForm->select($value['id'].'[content'.$contentID.']['.$cpt.'_matchValue]', FALSE, 'selectValue', $options, $postMatch, 'data-type="'.$cpt.'"');

																		echo $ctypForm->element('p', FALSE, FALSE, esc_html__('Please select a product filter type.','custom-thank-you-page'));

																	echo $ctypForm->elementEnd('div');

																	echo $ctypForm->element('div', FALSE, 'clear', FALSE);

																echo $ctypForm->elementEnd('div');

																echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box include ' . $cpt . 'cpt');

																	echo $ctypForm->elementStart('div', FALSE, 'input-left' );

																		echo $ctypForm->label('Include', esc_html__( 'WooCommerce products.', 'custom-thank-you-page'));

																	echo $ctypForm->elementEnd('div');

																	echo $ctypForm->elementStart('div', FALSE, 'input-right' );

																		$includeValues = isset($ctyp_setting['content' . $contentID]['include_' . $cpt]) ? $this->sanitize_postID_function($ctyp_setting['content' . $contentID]['include_' . $cpt]) : array('-1');

																		echo $ctypForm->ajaxSelect($value['id'].'[content'.$contentID.'][include_' . $cpt . ']', FALSE, 'ctypAjaxSelect2', $includeValues, $cpt);

																		echo $ctypForm->element('p', FALSE, FALSE, esc_html__('Type [All] to include all items.','custom-thank-you-page'));

																	echo $ctypForm->elementEnd('div');

																	echo $ctypForm->element('div', FALSE, 'clear', FALSE);

																echo $ctypForm->elementEnd('div');

																echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box exclude ' . $cpt . 'cpt');

																	echo $ctypForm->elementStart('div', FALSE, 'input-left' );

																		echo $ctypForm->label('Exclude', esc_html__( 'WooCommerce products.', 'custom-thank-you-page'));

																	echo $ctypForm->elementEnd('div');

																	echo $ctypForm->elementStart('div', FALSE, 'input-right' );

																		$excludeValues = isset($ctyp_setting['content' . $contentID]['exclude_' . $cpt]) ? $this->sanitize_postID_function($ctyp_setting['content' . $contentID]['exclude_' . $cpt]) : array('-1');

																		echo $ctypForm->ajaxSelect($value['id'].'[content'.$contentID.'][exclude_' . $cpt . ']', FALSE, 'ctypAjaxSelect2', $excludeValues, $cpt);

																		echo $ctypForm->element('p', FALSE, FALSE, esc_html__('Type [All] to exclude all items.','custom-thank-you-page'));

																	echo $ctypForm->elementEnd('div');

																	echo $ctypForm->element('div', FALSE, 'clear', FALSE);

																echo $ctypForm->elementEnd('div');

															echo $ctypForm->elementEnd('div');

														}

														$switchOrderDetails = ($ctyp_setting['content' . $contentID]['order_details'] && $ctyp_setting['content' . $contentID]['order_details'] == 'on') ? 'on' : 'off';

														echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box');

															echo $ctypForm->elementStart('div', FALSE, 'input-left' );

																echo $ctypForm->label(FALSE, esc_html__( 'Order details', 'custom-thank-you-page'));

															echo $ctypForm->elementEnd('div');

															echo $ctypForm->elementStart('div', FALSE, 'input-right' );

																echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'slider ' . $switchOrderDetails );

																	echo $ctypForm->elementStart('div', FALSE, 'inset' );
																	echo $ctypForm->element('div', FALSE, 'control orderDetails', FALSE);
																	echo $ctypForm->elementEnd('div');

																	echo $ctypForm->input($value['id'].'[content' .$contentID . '][order_details]', FALSE, 'on-off', 'hidden', $switchOrderDetails );

																echo $ctypForm->elementEnd('div');

																echo $ctypForm->element('div', FALSE, 'clear', FALSE);
																echo $ctypForm->element('p', FALSE, FALSE, __('If you want to disable the order details table, please select OFF. Important: When you disable the order details, the only available <strong>Content position option</strong> is <strong>after the order details</strong>)  .','custom-thank-you-page'));

															echo $ctypForm->elementEnd('div');

															echo $ctypForm->element('div', FALSE, 'clear', FALSE);

														echo $ctypForm->elementEnd('div');

														echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

															echo $ctypForm->elementStart('div', FALSE, 'input-left' );

																echo $ctypForm->label(FALSE, esc_html__( 'Content position', 'custom-thank-you-page'));

															echo $ctypForm->elementEnd('div');

															echo $ctypForm->elementStart('div', FALSE, 'input-right' );

																$position = isset($ctyp_setting['content' . $contentID]['position']) ? $ctyp_setting['content' . $contentID]['position'] : 'woocommerce_thankyou';

																$options = array(
																	'woocommerce_before_thankyou' => esc_html__('View the custom content before the order details','custom-thank-you-page'),
																	'woocommerce_thankyou' => esc_html__('View the custom content after the order details','custom-thank-you-page')
																);

																echo $ctypForm->select($value['id'].'[content'.$contentID.'][position]', FALSE, 'contentPosition', $options, $position, FALSE);
																echo $ctypForm->element('p', FALSE, FALSE, esc_html__('Please select the position of this content.','custom-thank-you-page'));

															echo $ctypForm->elementEnd('div');

															echo $ctypForm->element('div', FALSE, 'clear', FALSE);

														echo $ctypForm->elementEnd('div');

														echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box' );

															echo $ctypForm->elementStart('div', FALSE, 'default' );
															$savedContent = (isset($ctyp_setting['content' . $contentID]['content'])) ? $ctyp_setting['content' . $contentID]['content'] : '';
																wp_editor(

																	stripslashes($savedContent),
																	'customThankYouPageN' . $contentID,

																	array(
																		'drag_drop_upload' => true,
																		'editor_height' => '800px',
																		'textarea_name' => $value['id'] . '[content'.$contentID.'][content]',
																	)

																);

																echo $ctypForm->element('p', FALSE, FALSE, esc_html__('Put here the content of your final thank you page.','custom-thank-you-page'));

															echo $ctypForm->elementEnd('div');

															echo $ctypForm->element('div', FALSE, 'clear', FALSE);

														echo $ctypForm->elementEnd('div');

														echo $ctypForm->elementStart('div', FALSE, $plugin_slug . 'box deletePage' );

															echo $ctypForm->input('ctyp_save_content_action', FALSE, 'button ctyp_save_content', 'submit', esc_html__('Save content', 'custom-thank-you-page' ));
															echo $ctypForm->input('ctyp_delete_content_action', FALSE, 'button ctyp_delete_content', 'submit', esc_html__('Delete content', 'custom-thank-you-page' ));
															echo $ctypForm->element('div', FALSE, 'clear', FALSE);

														echo $ctypForm->elementEnd('div');

														echo $ctypForm->elementEnd('div');

														echo $ctypForm->elementEnd('div');

										}

										echo $ctypForm->elementEnd('div');

									echo $ctypForm->elementEnd('div');

								break;

								}

							endif;

						}

					}

				endif;

			}

		}

	}

}

?>
